@@ -1,15 +1,25 @@
-from .aoe2 import *
+"""
+A simple and basic Python 3 https://aoe2.net/ API wrapper for sending `GET requests`.
 
-__version__ = "0.2.0"
-__doc__ = """
-A simple and basic https://aoe2.net/ api wrapper for sending `GET requests`.
+Available on GitHub (+ documentation): https://github.com/sixP-NaraKa/aoe2net-api-wrapper
 
-Available on GitHub: https://github.com/sixP-NaraKa/aoe2net-api-wrapper
-
-Additional data manipulation/extraction from the provided data by this api wrapper has to be done by you, the user.
+Additional data manipulation/extraction from the provided data by this API wrapper has to be done by you, the user.
 
 See https://aoe2.net/#api & https://aoe2.net/#nightbot.
 
+MIT License. See `__license__` for more information.
+"""
+
+from sys import version_info
+
+if version_info.major < 3:
+    raise Exception("Python 3.X required.")
+
+# import the needed classes (also the custom exception)
+from .aoe2 import API, Nightbot, Aoe2NetException
+
+__version__ = "1.0.0"
+__license__ = """
 MIT License
 
 Copyright (c) 2020 sixP-NaraKa
